@@ -1,7 +1,7 @@
 package App::FilterOrgByHeadlines;
 
-our $DATE = '2015-04-03'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2015-05-02'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010;
 use strict;
@@ -112,6 +112,7 @@ _
             'summary.alt.bool.not' =>
                 "Don't include headline content, just print the headlines",
             default => 1,
+            tags => ['category:result'],
         },
         with_preamble => {
             schema => 'bool',
@@ -119,11 +120,17 @@ _
             'summary.alt.bool.not' =>
                 "Don't include text before any headline",
             default => 1,
+            tags => ['category:result'],
+        },
+        return_array => {
+            schema => ['bool*', is=>1],
+            summary => 'Return array of strings instead of strings',
+            tags => ['category:result'],
         },
     },
     result_naked => 1,
     result => {
-        schema => 'str*',
+        schema => ['any*', of=>['str*', ['array*', of=>'str*']]],
     },
 };
 sub filter_org_by_headlines {
@@ -146,7 +153,7 @@ sub filter_org_by_headlines {
     my $out;
   LINE:
     for my $line (ref($input) ? @$input : split(/^/, $input)) {
-        my $is_hl;
+        my $is_hl; # whether current line is a headline
         if ($line =~ /^#\+TODO:\s*(.+)/) {
             my $arg = $1;
             if (!$seen_todo_def++) {
@@ -232,7 +239,18 @@ sub filter_org_by_headlines {
 
             $include = 1;
         }
-        $out .= $line if $include;
+        if ($include) {
+            if ($args{return_array}) {
+                $out //= [];
+                if ($is_hl) {
+                    push @$out, $line;
+                } else {
+                    $out->[-1] .= $line;
+                }
+            } else {
+                $out .= $line;
+            }
+        }
     }
 
     $out;
@@ -253,12 +271,12 @@ App::FilterOrgByHeadlines - Filter Org by headlines
 
 =head1 VERSION
 
-This document describes version 0.30 of App::FilterOrgByHeadlines (from Perl distribution App-OrgUtils), released on 2015-04-03.
+This document describes version 0.31 of App::FilterOrgByHeadlines (from Perl distribution App-OrgUtils), released on 2015-05-02.
 
 =head1 FUNCTIONS
 
 
-=head2 filter_org_by_headlines(%args) -> str
+=head2 filter_org_by_headlines(%args) -> str|array[str]
 
 Filter Org by headlines.
 
@@ -307,6 +325,10 @@ Only include headline whose parent matches this.
 Value is either a string or a regex. If string is in the form of C</.../> or
 C</.../i> it is assumed to be a regex.
 
+=item * B<return_array> => I<bool>
+
+Return array of strings instead of strings.
+
 =item * B<with_content> => I<bool> (default: 1)
 
 Include headline content.
@@ -317,7 +339,7 @@ Include text before any headline.
 
 =back
 
-Return value:  (str)
+Return value:  (str|array[str])
 
 =head1 HOMEPAGE
 
@@ -325,7 +347,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
+Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
 
 =head1 BUGS
 
